summaryrefslogtreecommitdiffstats
path: root/runtime/nsd.h
diff options
context:
space:
mode:
Diffstat (limited to 'runtime/nsd.h')
-rw-r--r--runtime/nsd.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/runtime/nsd.h b/runtime/nsd.h
index 044cc266..1b3702a0 100644
--- a/runtime/nsd.h
+++ b/runtime/nsd.h
@@ -51,7 +51,8 @@ BEGINinterface(nsd) /* name must also be changed in ENDinterface macro! */
rsRetVal (*GetRemoteHName)(nsd_t *pThis, uchar **pszName);
rsRetVal (*GetRemoteIP)(nsd_t *pThis, uchar **pszIP);
rsRetVal (*GetSock)(nsd_t *pThis, int *pSock);
- /* GetSock() returns an error if the driver does not use plain
+ rsRetVal (*SetSock)(nsd_t *pThis, int sock);
+ /* GetSock() and SetSock() return an error if the driver does not use plain
* OS sockets. This interface is primarily meant as an internal aid for
* those drivers that utilize the nsd_ptcp to do some of their work.
*/